export declare const llmSubcommand: import("../../../types.ts").SubcommandDefinition;
export declare function generateLLMPrompt(): string;
export default llmSubcommand;
//# sourceMappingURL=llm.d.ts.map