export declare const webSubcommand: import("../../../types.ts").SubcommandDefinition;
/**
 * Get the raw prompt content without hash.
 */
export declare function getPromptContent(): string;
/**
 * Generate the web prompt with hash comment.
 */
export declare function generateLLMPrompt(): string;
//# sourceMappingURL=web.d.ts.map