import { createCommand } from "../../../../types.js";
import { listSubcommand } from "./list.js";
import { getSubcommand } from "./get.js";
export const outboundCommand = createCommand({
    name: 'outbound',
    description: 'Manage outbound (sent) emails',
    tags: ['requires-auth'],
    requires: { auth: true },
    subcommands: [listSubcommand, getSubcommand],
});
export default outboundCommand;
//# sourceMappingURL=index.js.map