/**
 * Generic build adapter.
 *
 * Handles any JS framework by:
 * 1. Installing dependencies
 * 2. Running the project's build script
 * 3. Copying the build output to the output directory
 *
 * This is the fallback for frameworks without a specific adapter,
 * and is also the base logic that specific adapters build on.
 */
import type { BuildAdapter } from './types.ts';
/**
 * Install dependencies using the detected package manager.
 */
export declare function installDependencies(projectDir: string, packageManager: string, logger: {
    debug: (...args: unknown[]) => void;
}): Promise<void>;
/**
 * Run the framework's build command.
 */
export declare function runBuildCommand(projectDir: string, buildCommand: string, packageManager: string, buildEnv?: Record<string, string>, logger?: {
    debug: (...args: unknown[]) => void;
}): Promise<{
    stdout: string;
    stderr: string;
}>;
export declare const genericAdapter: BuildAdapter;
//# sourceMappingURL=generic.d.ts.map