import { createCommand } from "../../../types.js";
import { llmSubcommand } from "./llm.js";
import { apiSubcommand } from "./api.js";
import { webSubcommand } from "./web.js";
import { getCommand } from "../../../command-prefix.js";
export const promptCommand = createCommand({
    name: 'prompt',
    description: 'Generate prompts for LLMs',
    tags: ['read-only', 'fast'],
    examples: [
        { command: getCommand('ai prompt llm'), description: 'Generate LLM-specific prompt' },
        {
            command: getCommand('ai prompt api'),
            description: 'Generate LLM-specific prompt for APIs',
        },
        { command: getCommand('ai prompt web'), description: 'Generate LLM-specific prompt for Web' },
    ],
    subcommands: [webSubcommand, llmSubcommand, apiSubcommand],
});
export default promptCommand;
//# sourceMappingURL=index.js.map